==> redux-connected-0.0.4.tgz: package/src/sagas/_utils/api.ts <==
import { ResponseBuilder } from './ResponseBuilder';
import { ApiRequest, ApiServerConfiguration } from './../../types/types';
import axios, { AxiosInstance } from 'axios';
import { Json } from 'redux-store-generator';

export let instance: AxiosInstance;

export const DEFAULT_API_ENDPOINTS_CONFIGURATION = {
    internetConnectionCheckUrl: 'https://www.google.com',
};

export const configureAxiosInstance = (
    apiServerConfiguration: ApiServerConfiguration
) => {
    const configuration = {
        ...DEFAULT_API_ENDPOINTS_CONFIGURATION,
        ...apiServerConfiguration,
    };

    instance = axios.create({
        baseURL: configuration.baseURL,
        timeout: configuration.timeout,
        headers: configuration.headers,
    });
};

export const api = {
    get: (path: string) => instance.get(path),
    post: (path: string, data?: Json) => instance.post(path, data),
    patch: (path: string, data?: Json) => instance.patch(path, data),
    put: (path: string, data?: Json) => instance.put(path, data),
    delete: (path: string) => instance.delete(path),
};

export const fireRequest = (request: ApiRequest) => {
    const { method, path, params } = request;

    const response = new ResponseBuilder(request);

    return new Promise((resolve) => {
        let reqPromise;

        switch (method) {
            case 'GET':
                reqPromise = api.get(path);
                break;
            case 'POST':
                reqPromise = api.post(path, params);
                break;
            case 'PATCH':
                reqPromise = api.patch(path, params);
                break;
            case 'DELETE':
                reqPromise = api.delete(path);
                break;
            case 'PUT':
                reqPromise = api.put(path, params);
                break;
        }

        reqPromise
            .then((res) => {
                response.withIsSuccess(true).withAxiosResponse(res);
            })
            .catch(function (error) {
                if (error.response) {
                    // The request was made and the server responded with a status code
                    // that falls out of the range of 2xx
                    const { status } = error.response;

                    const errorType =
                        status === 401 ? 'authorization' : 'server';

                    response
                        .withErrorType(errorType)
                        .withAxiosResponse(error.response);
                } else if (error.request) {
                    // The request was made but no response was received
                    // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
                    // http.ClientRequest in node.js
                    response.withErrorType('timeout');
                } else {
                    // Something happened in setting up the request that triggered an Error
                    response
                        .withErrorType('javascript')
                        .withErrorMessage(error.message);
                }
            })
            .finally(() => {
                resolve(response.build());
            });
    });
};

export const checkConnection = (url: string): Promise<boolean> => {
    return new Promise((resolve) => {
        axios
            .get(url)
            .then(() => {
                resolve(true);
            })
            .catch(function () {
                resolve(false);
            });
    });
};

==> redux-connected-0.0.6.tgz: package/src/sagas/_utils/api.ts <==
import { ResponseBuilder } from './ResponseBuilder';
import { ApiRequest, ApiServerConfiguration } from './../../types/types';
import axios, { AxiosInstance } from 'axios';
import { Json } from 'redux-store-generator';

export let instance: AxiosInstance;

export const DEFAULT_API_ENDPOINTS_CONFIGURATION = {
    internetConnectionCheckUrl: 'https://www.google.com',
};

export const configureAxiosInstance = (
    apiServerConfiguration: ApiServerConfiguration
) => {
    const configuration = {
        ...DEFAULT_API_ENDPOINTS_CONFIGURATION,
        ...apiServerConfiguration,
    };

    instance = axios.create({
        baseURL: configuration.baseURL,
        timeout: configuration.timeout,
        headers: configuration.headers,
    });
};

export const api = {
    get: (path: string, params?: Json) => instance.get(path, { params }),
    post: (path: string, data?: Json) => instance.post(path, data),
    patch: (path: string, data?: Json) => instance.patch(path, data),
    put: (path: string, data?: Json) => instance.put(path, data),
    delete: (path: string) => instance.delete(path),
};

export const fireRequest = (request: ApiRequest) => {
    const { method, path, params } = request;

    const response = new ResponseBuilder(request);

    return new Promise((resolve) => {
        let reqPromise;

        switch (method) {
            case 'GET':
                reqPromise = api.get(path, params);
                break;
            case 'POST':
                reqPromise = api.post(path, params);
                break;
            case 'PATCH':
                reqPromise = api.patch(path, params);
                break;
            case 'DELETE':
                reqPromise = api.delete(path);
                break;
            case 'PUT':
                reqPromise = api.put(path, params);
                break;
        }

        reqPromise
            .then((res) => {
                response.withIsSuccess(true).withAxiosResponse(res);
            })
            .catch(function (error) {
                if (error.response) {
                    // The request was made and the server responded with a status code
                    // that falls out of the range of 2xx
                    const { status } = error.response;

                    const errorType =
                        status === 401 ? 'authorization' : 'server';

                    response
                        .withErrorType(errorType)
                        .withAxiosResponse(error.response);
                } else if (error.request) {
                    // The request was made but no response was received
                    // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
                    // http.ClientRequest in node.js
                    response.withErrorType('timeout');
                } else {
                    // Something happened in setting up the request that triggered an Error
                    response
                        .withErrorType('javascript')
                        .withErrorMessage(error.message);
                }
            })
            .finally(() => {
                resolve(response.build());
            });
    });
};

export const checkConnection = (url: string): Promise<boolean> => {
    return new Promise((resolve) => {
        axios
            .get(url)
            .then(() => {
                resolve(true);
            })
            .catch(function () {
                resolve(false);
            });
    });
};
